package net.carbon.interceptor;

import io.jsonwebtoken.Claims;
import lombok.extern.slf4j.Slf4j;

import net.carbon.enums.BizCodeEnum;
import net.carbon.model.LoginUser;
import net.carbon.utils.CommonUtil;
import net.carbon.utils.JWTUtil;
import net.carbon.utils.JsonData;
import org.apache.commons.lang3.StringUtils;
import org.springframework.web.servlet.HandlerInterceptor;
import org.springframework.web.servlet.ModelAndView;

import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;


@Slf4j
public class LoginInterceptor implements HandlerInterceptor {

    public static ThreadLocal<LoginUser> threadLocal = new ThreadLocal<>();

    @Override
    public boolean preHandle(HttpServletRequest request, HttpServletResponse response, Object handler) throws Exception {
        String accessToken = request.getHeader("token");

        if (accessToken == null) {
            accessToken = request.getParameter("token");
        }

        //不为空
        if (StringUtils.isNotBlank(accessToken)) {
            Claims claims = JWTUtil.checkJWT(accessToken);
            if (claims == null) {
                //未登录
                CommonUtil.sendJsonMessage(response, JsonData.buildResult(BizCodeEnum.ACCOUNT_UNLOGIN));
                return false;
            }
            long userId = Long.valueOf(claims.get("id").toString());
            String name = (String) claims.get("username");

            LoginUser loginUser = LoginUser.builder()
                    .id(userId)
                    .username(name)
                    .build();

            //通过threadlocal传递用户信息
            threadLocal.set(loginUser);
            return true;
        }
        //未登录
        CommonUtil.sendJsonMessage(response, JsonData.buildResult(BizCodeEnum.ACCOUNT_UNLOGIN));
        return false;
    }

    @Override
    public void postHandle(HttpServletRequest request, HttpServletResponse response, Object handler, ModelAndView modelAndView) throws Exception {
    }

    @Override
    public void afterCompletion(HttpServletRequest request, HttpServletResponse response, Object handler, Exception ex) throws Exception {
    }
}
