package net.carbon.controller;


import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import net.carbon.bean.PageResponse;
import net.carbon.model.po.LabelDO;
import net.carbon.model.request.LabelUpdateRequest;
import net.carbon.model.vo.LabelVO;
import net.carbon.result.Result;
import net.carbon.service.LabelService;
import net.carbon.utils.JsonData;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.stream.Collectors;

/**
 * <p>
 * 碳排放-城市高质量发展指标体系-标签表 前端控制器
 * </p>
 *
 * @author jieyuu
 * @since 2025-02-19
 */
@RestController
@RequestMapping("/api/label/v1")
public class LabelController {
    @Autowired
    private LabelService labelService;

    // 获取所有指标
    @GetMapping("/list")
    public Result<PageResponse<LabelVO>> getAllIndicators(@RequestParam("pageSize") Long pageSize, @RequestParam("current") Long current) {
        return Result.success(labelService.getList(pageSize, current));
    }

//    // 新增指标
//    @PostMapping("/create")
//    public Result<LabelDO> createIndicator(@RequestBody LabelDO label) {
//        boolean save = labelService.save(label);
//        if (save) {
//            return Result.success();
//        }
//        return Result.error("创建失败");
//    }

    // 生成编辑接口
    @PostMapping("/update")
    public Result update(@RequestBody LabelUpdateRequest labelUpdateReq) {
        int row = labelService.updateById(labelUpdateReq);
        if (row > 0) {
            return Result.success();
        }
        return Result.error("修改失败");
    }

    // 剔除指标
    @DeleteMapping("/delete/{id}")
    public Result delete(@PathVariable("id") Long id) {
        int row = labelService.delete(id);
        if (row > 0) {
            return Result.success();
        }
        return Result.error("删除失败");
    }


    @PostMapping("/add")
    public JsonData add(@RequestBody LabelUpdateRequest labelUpdateRequest){
        int row = labelService.add(labelUpdateRequest);
        if (row >0){
            return JsonData.buildCodeAndMsg(1,"添加成功");
        }
        return JsonData.buildError("添加失败");
    }
}

